This takes two arguments, just like gsub: a pattern and a replacement.
It overwrites only the matched portion of each element of x. If you
want to overwrite whole elements that match (rather than just the matched
portion), use %regex<-% instead.
Value
Used for the side effect of reassigning x in the calling
environment; returns the modified x invisibly.
Author
Ben Wiseman, benjamin.h.wiseman@gmail.com