%na<-% is a shortcut to assign a value to all NA elements of
x. The replacement may be a single value (recycled to every NA),
a vector with one entry per missing element (filled in order), or a vector the
same length as x (its values at the missing positions are used).
Value
Used for the side effect of reassigning x in the calling
environment; returns the modified x invisibly.
Author
Ben Wiseman, benjamin.h.wiseman@gmail.com